==> mediawiki-1.12.4.tbz: www/mediawiki/languages/messages/MessagesBi.php <==
<?php
/** Bislama (Bislama)
 *
 * @ingroup Language
 * @file
 *
 * @author Ushanka
 */

$messages = array(
'underline-always' => 'Oltaem',
'underline-never'  => 'Neva',

# Dates
'sunday'        => 'Sande',
'monday'        => 'Mande',
'tuesday'       => 'Tusde',
'wednesday'     => 'Wenesde',
'thursday'      => 'Tosde',
'friday'        => 'Fraede',
'saturday'      => 'Sarede',
'sun'           => 'San',
'mon'           => 'Man',
'tue'           => 'Tu',
'wed'           => 'Wen',
'thu'           => 'To',
'fri'           => 'Frae',
'sat'           => 'Sar',
'january'       => 'Januware',
'february'      => 'Februari',
'march'         => 'Maj',
'april'         => 'Epril',
'may_long'      => 'Mei',
'june'          => 'Jun',
'july'          => 'Julae',
'august'        => 'Ogis',
'september'     => 'Septemba',
'october'       => 'Oktoba',
'november'      => 'Novemba',
'december'      => 'Desemba',
'january-gen'   => 'Januware',
'february-gen'  => 'Februari',
'march-gen'     => 'Maj',
'april-gen'     => 'Epril',
'may-gen'       => 'Mei',
'june-gen'      => 'Jun',
'july-gen'      => 'Julae',
'august-gen'    => 'Ogis',
'september-gen' => 'Septemba',
'october-gen'   => 'Oktoba',
'november-gen'  => 'Novemba',
'december-gen'  => 'Desemba',
'mar'           => 'Maj',
'apr'           => 'Epr',
'may'           => 'Mei',
'aug'           => 'Ogis',
'oct'           => 'Okt',
'dec'           => 'Des',

'qbedit'         => 'Jenisim hem',
'qbpageoptions'  => 'Pej ia',
'qbmyoptions'    => 'Ol pej blong mi',
'qbspecialpages' => 'Ol spesel pej',
'mypage'         => 'Pej blong mi',
'mytalk'         => 'Tingting blong mi',
'and'            => 'mo',

'edit'             => 'Jenisim hem',
'newpage'          => 'Mekem niu pej',
'talkpagelinktext' => 'Toktok',
'specialpage'      => 'Spesel Pej',
'talk'             => 'Tingting',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'mainpage' => 'Nambawan Pej',

'retrievedfrom' => 'Kam long "$1"',
'editsection'   => 'jenisim hem',
'editold'       => 'jenisim hem',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'    => 'Atikel',
'nstab-special' => 'Spesel',

# Edit pages
'minoredit' => 'Mi bin mekem wan smol jenis',

# Preferences page
'servertime' => 'Taem blong server',

# Image list
'imagelist_name' => 'Nem',

# Miscellaneous special pages
'shortpages' => 'Ol smol pej',
'longpages'  => 'Ol big pej',
'newpages'   => 'Ol niu pej',

# Special:Allpages
'allarticles' => 'Olgeta atikel',

# E-mail user
'emailfrom' => 'Kam long',
'emailto'   => 'Go long:',

# Contributions
'year' => 'Yia:',

# Block/unblock
'proxyblocksuccess' => 'Finis.',

# Move page
'movepage'    => 'Muvum pej',
'movearticle' => 'Muvum pej:',

# Namespace 8 related
'allmessagesname' => 'Nem',

# Tooltip help for the actions
'tooltip-pt-mytalk'  => 'Pej blong tingting blong mi',
'tooltip-p-logo'     => 'Nambawan Pej',
'tooltip-n-mainpage' => 'Go long Nambawan Pej',
'tooltip-minoredit'  => 'Em i stap wan smol jenis',

# Special:Newimages
'showhidebots' => '($1 bot)',

# EXIF tags
'exif-imagedescription'    => 'Nem blong pikta',
'exif-exposuretime-format' => '$1 sek. ($2)',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'olgeta',
'imagelistall'     => 'olgeta',
'watchlistall2'    => 'olgeta',
'namespacesall'    => 'olgeta',
'monthsall'        => 'olgeta',

# Multipage image navigation
'imgmultigotopre' => 'Go long pej',

# Table pager
'table_pager_first' => 'Nambawan pej',

# Auto-summaries
'autosumm-new' => 'Niu pej: $1',

);

==> mediawiki-1.15.5.tbz: www/mediawiki/languages/messages/MessagesBi.php <==
<?php
/** Bislama (Bislama)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Ushanka
 */

$messages = array(
'underline-always' => 'Oltaem',
'underline-never'  => 'Neva',

# Dates
'sunday'        => 'Sande',
'monday'        => 'Mande',
'tuesday'       => 'Tusde',
'wednesday'     => 'Wenesde',
'thursday'      => 'Tosde',
'friday'        => 'Fraede',
'saturday'      => 'Sarede',
'sun'           => 'San',
'mon'           => 'Man',
'tue'           => 'Tu',
'wed'           => 'Wen',
'thu'           => 'To',
'fri'           => 'Frae',
'sat'           => 'Sar',
'january'       => 'Januware',
'february'      => 'Februari',
'march'         => 'Maj',
'april'         => 'Epril',
'may_long'      => 'Mei',
'june'          => 'Jun',
'july'          => 'Julae',
'august'        => 'Ogis',
'september'     => 'Septemba',
'october'       => 'Oktoba',
'november'      => 'Novemba',
'december'      => 'Desemba',
'january-gen'   => 'Januware',
'february-gen'  => 'Februari',
'march-gen'     => 'Maj',
'april-gen'     => 'Epril',
'may-gen'       => 'Mei',
'june-gen'      => 'Jun',
'july-gen'      => 'Julae',
'august-gen'    => 'Ogis',
'september-gen' => 'Septemba',
'october-gen'   => 'Oktoba',
'november-gen'  => 'Novemba',
'december-gen'  => 'Desemba',
'mar'           => 'Maj',
'apr'           => 'Epr',
'may'           => 'Mei',
'aug'           => 'Ogis',
'oct'           => 'Okt',
'dec'           => 'Des',

'qbedit'         => 'Jenisim hem',
'qbpageoptions'  => 'Pej ia',
'qbmyoptions'    => 'Ol pej blong mi',
'qbspecialpages' => 'Ol spesel pej',
'mypage'         => 'Pej blong mi',
'mytalk'         => 'Tingting blong mi',
'and'            => '&#32;mo',

'edit'             => 'Jenisim hem',
'newpage'          => 'Mekem niu pej',
'talkpagelinktext' => 'Toktok',
'specialpage'      => 'Spesel Pej',
'talk'             => 'Tingting',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'mainpage'             => 'Nambawan Pej',
'mainpage-description' => 'Nambawan Pej',

'retrievedfrom' => 'Kam long "$1"',
'editsection'   => 'jenisim hem',
'editold'       => 'jenisim hem',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'    => 'Atikel',
'nstab-special' => 'Spesel',

# Edit pages
'minoredit' => 'Mi bin mekem wan smol jenis',

# Preferences page
'servertime' => 'Taem blong server',

# Special:ListFiles
'listfiles_name' => 'Nem',

# Miscellaneous special pages
'shortpages' => 'Ol smol pej',
'longpages'  => 'Ol big pej',
'newpages'   => 'Ol niu pej',

# Special:AllPages
'allarticles' => 'Olgeta atikel',

# E-mail user
'emailfrom' => 'Kam long',
'emailto'   => 'Go long:',

# Contributions
'year' => 'Yia:',

# Block/unblock
'proxyblocksuccess' => 'Finis.',

# Move page
'move-page-legend' => 'Muvum pej',
'movearticle'      => 'Muvum pej:',

# Namespace 8 related
'allmessagesname' => 'Nem',

# Tooltip help for the actions
'tooltip-pt-mytalk'  => 'Pej blong tingting blong mi',
'tooltip-p-logo'     => 'Nambawan Pej',
'tooltip-n-mainpage' => 'Go long Nambawan Pej',
'tooltip-minoredit'  => 'Em i stap wan smol jenis',

# Special:NewFiles
'showhidebots' => '($1 bot)',

# EXIF tags
'exif-imagedescription'    => 'Nem blong pikta',
'exif-exposuretime-format' => '$1 sek. ($2)',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'olgeta',
'imagelistall'     => 'olgeta',
'watchlistall2'    => 'olgeta',
'namespacesall'    => 'olgeta',
'monthsall'        => 'olgeta',

# Table pager
'table_pager_first' => 'Nambawan pej',

# Auto-summaries
'autosumm-new' => 'Niu pej: $1',

);
